@@ -4,33 +4,8 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright (C) 2012-2024 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of the software contained in this package
-# as well as the source package itself are made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this package provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use the software under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2012-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 import codecs
 import logging
@@ -59,13 +34,25 @@ def convert_ucs_debuglevel(ucs_debuglevel: int) -> int:
     return logging_debuglevel
 
 
-def get_ldapConnection() -> univention.uldap.access:
+def get_ldapConnection(logger: logging.Logger | None = None) -> univention.uldap.access:
+    secret_file = '/etc/freeradius.secret'
+    if logger is None:
+        logger = logging.getLogger('radius-ntlm')
+
+    # check if file is readable
+    try:
+        with open(secret_file) as fd:
+            fd.read()
+    except OSError as exc:
+        logger.critical('Unable to read %r: %s', secret_file, exc)
+        raise
+
     try:
         # try ldap/server/name, then each of ldap/server/addition
-        return univention.uldap.getMachineConnection(ldap_master=False, reconnect=False, secret_file='/etc/freeradius.secret')
+        return univention.uldap.getMachineConnection(ldap_master=False, reconnect=False, secret_file=secret_file)
     except SERVER_DOWN:
         # then primary directory node
-        return univention.uldap.getMachineConnection(secret_file='/etc/freeradius.secret')
+        return univention.uldap.getMachineConnection(secret_file=secret_file)
 
 
 class NetworkAccessError(Exception):
@@ -95,7 +82,6 @@ class NetworkAccess:
     def __init__(self, username: str, stationId: str, loglevel: int | None = None, logfile: str | None = None) -> None:
         self.username = parse_username(username)
         self.mac_address = decode_stationId(stationId)
-        self.ldapConnection = get_ldapConnection()
         self.configRegistry = univention.config_registry.ConfigRegistry()
         self.configRegistry.load()
         self.use_ssp = self.configRegistry.is_true('radius/use-service-specific-password')
@@ -103,6 +89,13 @@ class NetworkAccess:
         self._setup_logger(loglevel, logfile)
         self.logger.debug('Given username: %r', username)
         self.logger.debug('Given stationId: %r', stationId)
+        self._ldapConnection = None
+
+    @property
+    def ldapConnection(self):
+        if self._ldapConnection is None:
+            self._ldapConnection = get_ldapConnection(logger=self.logger)
+        return self._ldapConnection
 
     def _setup_logger(self, loglevel: int | None, logfile: str | None) -> None:
         if loglevel is not None:
@@ -214,7 +207,7 @@ class NetworkAccess:
         else:
             result = self.ldapConnection.search(filter=filter_format('(|(uid=%s)(macAddress=%s))', (self.username, self.username)), attr=[pwd_attr, 'sambaAcctFlags'])
         try:
-            nt_password_hash = codecs.decode(result[0][1][pwd_attr][0], 'hex')
+            nt_password_hash: bytes = codecs.decode(result[0][1][pwd_attr][0], 'hex')
         except (IndexError, KeyError, TypeError):
             raise NoHashError('No valid NT-password-hash found. Check the "%s" attribute of the user.' % (pwd_attr,))
         sambaAccountFlags = frozenset(result[0][1]['sambaAcctFlags'][0].decode('UTF-8'))
